@@ -1,9 +1,27 @@
 from django.contrib.auth.models import User
+from django.core.exceptions import ObjectDoesNotExist
 from django.db.models import Q
 from django.template.defaultfilters import slugify
 from django.utils import timezone
 from django.utils.translation import get_language
 
+from hvad.utils import get_translation
+
+from .conf import settings
+
+
+def get_blog_languages():
+    from .models import Post
+
+    langs = []
+    for post in Post.objects.all():
+        if not post.language:
+            # at least one post is available in all languages
+            return settings.languages
+        if post.language not in langs:
+            langs.append(post.language)
+    return langs
+
 
 def get_blog_authors():
     now = timezone.now()
@@ -61,3 +79,17 @@ def get_slug_for_user(find_user):
     for author in authors:
         if author == find_user:
             return author.slug
+
+
+def get_slug_in_language(record, language):
+    if not record:
+        return None
+    if hasattr(record, record._meta.translations_cache) and language == record.language_code:  # possibly no need to hit db, try cache
+        return record.lazy_translation_getter('slug')
+    else:  # hit db
+        try:
+            translation = get_translation(record, language_code=language)
+        except ObjectDoesNotExist:
+            return None
+        else:
+            return translation.slug
